@@ -1,5 +1,5 @@
 # texttable - module for creating simple ASCII tables
-# Copyright (C) 2003-2018 Gerome Fournier <jef(at)foutaise.org>
+# Copyright (C) 2003-2019 Gerome Fournier <jef(at)foutaise.org>
 
 """module for creating simple ASCII tables
 
@@ -62,7 +62,7 @@ __all__ = ["Texttable", "ArraySizeError"]
 
 __author__ = 'Gerome Fournier <jef(at)foutaise.org>'
 __license__ = 'MIT'
-__version__ = '1.6.0'
+__version__ = '1.6.2'
 __credits__ = """\
 Jeff Kowalczyk:
     - textwrap improved import
@@ -483,11 +483,12 @@ class Texttable:
         f = cls._to_float(x)
         if abs(f) > 1e8:
             fn = cls._fmt_exp
+        elif f != f:  # NaN
+            fn = cls._fmt_text
+        elif f - round(f) == 0:
+            fn = cls._fmt_int
         else:
-            if f - round(f) == 0:
-                fn = cls._fmt_int
-            else:
-                fn = cls._fmt_float
+            fn = cls._fmt_float
         return fn(x, **kw)
 
     def _str(self, i, x):
